@@ -25,44 +25,69 @@ from abc import ABC, abstractmethod
 #-----------------------------------------------------#
 #         Abstract Base Class for XAI Methods         #
 #-----------------------------------------------------#
-""" An abstract base class for a XAI Method class.
-
-Methods:
-    __init__                Object creation function.
-    compute_heatmap:        Application of the XAI Method on an image.
-"""
 class XAImethod_Base(ABC):
-    #---------------------------------------------#
-    #                Initialization               #
-    #---------------------------------------------#
-    """ Initialization function for creating a XAI Method object.
+    """ An abstract base class for a XAI Method class.
+
     Normally, this class is used internally in the xai_decoder function in the AUCMEDI XAI module.
 
     This class provides functionality for running the compute_heatmap function,
     which computes a heatmap for an image with a model.
 
-    Args:
-        model (Keras Model):               Keras model object.
-        layerName (String):                Layer name of the convolutional layer for heatmap computation.
+    ???+ example "Create a custom XAImethod"
+        ```python
+        from aucmedi.xai.methods.xai_base import XAImethod_Base
+
+        class My_custom_XAImethod(XAImethod_Base):
+            def __init__(self, model, layerName=None):
+                pass
+
+            def compute_heatmap(self, image, class_index, eps=1e-8):
+                pass
+        ```
+
+    ???+ info "Required Functions"
+        | Function            | Description                                |
+        | ------------------- | ------------------------------------------ |
+        | `__init__()`        | Object creation function.                  |
+        | `compute_heatmap()` | Application of the XAI Method on an image. |
+
     """
+    #---------------------------------------------#
+    #                Initialization               #
+    #---------------------------------------------#
     @abstractmethod
     def __init__(self, model, layerName=None):
+        """ Initialization function for creating a XAI Method object.
+        ```
+        __init__(model, layerName=None)
+        ```
+
+        Args:
+            model (keras.model):               Keras model object.
+            layerName (str):                Layer name of the convolutional layer for heatmap computation.
+        """
         pass
 
     #---------------------------------------------#
     #             Heatmap Computation             #
     #---------------------------------------------#
-    """ Core function for computing the XAI heatmap for a provided image and for specific classification outcome.
+    def compute_heatmap(self, image, class_index, eps=1e-8):
+        """ Core function for computing the XAI heatmap for a provided image and for specific classification outcome.
 
-    The shape of the returned heatmap is 2D -> batch and channel axis will be removed.
-    The returned heatmap should be encoded with a range of [0,1]
+        ???+ attention
+            Be aware that the image has to be provided in batch format.
 
-    Be aware that the image has to be provided in batch format.
+        Args:
+            image (numpy.ndarray):              Image matrix encoded as NumPy Array (provided as one-element batch).
+            class_index (int):                  Classification index for which the heatmap should be computed.
+            eps (float):                        Epsilon for rounding.
 
-    Args:
-        image (NumPy Array):                Image matrix encoded as NumPy Array (provided as one-element batch).
-        class_index (Integer):              Classification index for which the heatmap should be computed.
-        eps (Float):                        Epsilon for rounding.
-    """
-    def compute_heatmap(self, image, class_index):
+        The returned heatmap should be encoded within a range of [0,1]
+
+        ???+ attention
+            The shape of the returned heatmap is 2D -> batch and channel axis will be removed.
+
+        Returns:
+            heatmap (numpy.ndarray):            Computed XAI heatmap for provided image.
+        """
         pass
